==> 0.0.1.tar.gz: lib/src/darbird.dart <==

import 'package:darbirdsms/darbirdsms.dart';
import 'package:meta/meta.dart';
import 'package:dio/dio.dart';

class Darbird {
  /// Darbird Api key
  String _ApiKey;

  /// Darbird access token
  String _CusID;

  String _SenderID;

  /// Darbird base URL
  final String _baseURL = 'https://api.darbird.com/api/';

  Dio _client;

  /// To initialize Darbird message transactions
  /// using [apikey] and [cusId]
  Darbird.initialize({
    @required String apikey,
    @required String cusId,
    @required String senderID,
  }) {
    if (apikey == null) {
      throw IsNullException('Api key cannot be null');
    }
    if (cusId == null) {
      throw IsNullException('Customer ID cannot be null');
    }
    if (senderID == null) {
      throw IsNullException('Sender ID cannot be null');
    }
    this._ApiKey = apikey;
    this._CusID = cusId;
    this._SenderID = senderID;
    _initializeDio();
  }

  /// Initialize Dio client for network requests
  void _initializeDio() {
    _client = Dio(BaseOptions(baseUrl: _baseURL));
  }

  /// To send SMS
  /// [from] - Sender ID (alphanumeric/alphabetic)
  /// [to] - Receipient's mobile number
  /// [message] - Message being sent
  Future sendSMS({
    @required String unicode,
    @required String to,
    @required String message,
  }) async {
    Map responseBody;
    var returnable;
    try {
      final response = await _client.post(
        'sms/api',
        data: {
          "to": to,
          "from": _SenderID,
          "sms": message,
          "unicode": unicode,
          "action": "send-sms",
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        returnable =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send SMS");
      }
    }
    return returnable;
  }

  Future sendVoice({
    @required String to,
    @required String message,
  }) async {
    Map responseBody;
    var returnable;
    try {
      final response = await _client.post(
        'sms/api',
        data: {
          "to": to,
          "voice": "1",
          "from": _SenderID,
          "sms": message,
          "unicode": "1",
          "action": "send-sms",
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        returnable =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send Voice");
      }
    }
    return returnable;
  }


  Future sendMMS({
    @required String unicode,
    @required String to,
    @required String message,
    @required String media_url,
  }) async {
    Map responseBody;
    var returnable;
    try {
      final response = await _client.post(
        'sms/api',
        data: {
          "to": to,
          "mms": "1",
          "from": _SenderID,
          "sms": message,
          "media_url": media_url,
          "unicode": "1",
          "action": "send-sms",
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        returnable =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send Voice");
      }
    }
    return returnable;
  }


  Future sendSchedule({
    @required String unicode,
    @required String to,
    @required String message,
    @required String schedule,
  }) async {
    Map responseBody;
    var returnable;
    try {
      final response = await _client.post(
        'sms/api',
        data: {
          "to": to,
          "mms": "1",
          "from": _SenderID,
          "sms": message,
          "schedule": schedule,
          "unicode": "1",
          "action": "send-sms",
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        returnable =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send Voice");
      }
    }
    return returnable;
  }


  Future sendAuthty({
    @required String to_number,
    @required String token_lenght,
    @required String type,
    @required String message,

  }) async {
    Map responseBody;
    var returnable;
    try {
      final response = await _client.post(
        'sms/api',
        data: {
          "to_number": to_number,
          "token_lenght": token_lenght,
          "msg_type": type,
          "message": message
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        returnable =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send Voice");
      }
    }
    return returnable;
  }


  Future verifyAuthty({
    @required String to_number,
    @required String auth_code,
  }) async {
    Map responseBody;
    var returnable;
    try {
      final response = await _client.post(
        'sms/api',
        data: {
          "to_number": to_number,
          "auth_code": auth_code,
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        returnable =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send Voice");
      }
    }
    return returnable;
  }
}

==> 0.0.6.tar.gz: lib/src/darbird.dart <==

import 'package:darbirdsms/darbirdsms.dart';
import 'package:meta/meta.dart';
import 'package:dio/dio.dart';

class Darbird {
  /// Darbird Api key
  String _ApiKey;

  /// Darbird access token
  String _CusID;

  String _SenderID;

  /// Darbird base URL
  final String _baseURL = 'https://api.darbird.com/api/';

  Dio _client;

  /// To initialize Darbird message transactions
  /// using [apikey] and [cusId]
  Darbird.initialize({
    @required String apikey,
    @required String cusId,
    @required String senderID,
  }) {
    if (apikey == null) {
      throw IsNullException('Api key cannot be null');
    }
    if (cusId == null) {
      throw IsNullException('Customer ID cannot be null');
    }
    if (senderID == null) {
      throw IsNullException('Sender ID cannot be null');
    }
    this._ApiKey = apikey;
    this._CusID = cusId;
    this._SenderID = senderID;
    _initializeDio();
  }

  /// Initialize Dio client for network requests
  void _initializeDio() {
    _client = Dio(BaseOptions(baseUrl: _baseURL));
  }

  /// To send SMS
  /// [from] - Sender ID (alphanumeric/alphabetic)
  /// [to] - Receipient's mobile number
  /// [message] - Message being sent
  Future sendSMS({
    @required String unicode,
    @required String to,
    @required String message,
  }) async {
    Map responseBody;
    
    try {
      final response = await _client.post(
        'sms/api',
        data: {
          "to": to,
          "from": _SenderID,
          "sms": message,
          "unicode": unicode,
          "action": "send-sms",
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        responseBody =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send SMS");
      }
    }
    return responseBody;
  }

  Future sendVoice({
    @required String to,
    @required String message,
  }) async {
    Map responseBody;
    
    try {
      final response = await _client.post(
        'sms/api',
        data: {
          "to": to,
          "voice": "1",
          "from": _SenderID,
          "sms": message,
          "unicode": "1",
          "action": "send-sms",
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        responseBody =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send Voice");
      }
    }
    return responseBody;
  }


  Future sendMMS({
    @required String unicode,
    @required String to,
    @required String message,
    @required String media_url,
  }) async {
    Map responseBody;
    
    try {
      final response = await _client.post(
        'sms/api',
        data: {
          "to": to,
          "mms": "1",
          "from": _SenderID,
          "sms": message,
          "media_url": media_url,
          "unicode": "1",
          "action": "send-sms",
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        responseBody =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send Voice");
      }
    }
    return responseBody;
  }


  Future sendSchedule({
    @required String unicode,
    @required String to,
    @required String message,
    @required String schedule,
  }) async {
    Map responseBody;
    
    try {
      final response = await _client.post(
        'sms/api',
        data: {
          "to": to,
          "mms": "1",
          "from": _SenderID,
          "sms": message,
          "schedule": schedule,
          "unicode": "1",
          "action": "send-sms",
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        responseBody =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send Voice");
      }
    }
    return responseBody;
  }


  Future sendAuthty({
    @required String to_number,
    @required String token_lenght,
    @required String type,
    @required String message,

  }) async {
    Map responseBody;
    
    try {
      final response = await _client.post(
        'auth/autity',
        data: {
          "to_number": to_number,
          "token_lenght": token_lenght,
          "msg_type": type,
          "from": _SenderID,
          "message": message
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        responseBody =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send Voice");
      }
    }
    return responseBody;
  }


  Future verifyAuthty({
    @required String to_number,
    @required String auth_code,
  }) async {
    Map responseBody;
    
    try {
      final response = await _client.post(
        'auth/confirm-token',
        data: {
          "to_number": to_number,
          "auth_code": auth_code,
        },
        options: RequestOptions(
          headers: {
            "X-Darbird-Token":_ApiKey,
            "X-Darbird-Key":_CusID
          },
        ),
      );

      if (response.statusCode == 200) {
        responseBody =  response.data;
      }
    } on DioError catch (error) {
      if (error.response != null) {
        var response = error.response;
        responseBody = response.data;
        if (response.statusCode == 401) {
          throw FailedAuthException(responseBody['error']);
        } else if (response.statusCode == 400) {
          throw SMSDetailsException(
              responseBody[responseBody.keys.elementAt(0)]);
        }
      } else {
        throw Exception("Failed to send Voice");
      }
    }
    return responseBody;
  }
}
